class ExtractClass:
    def get_date_items(self):
        return self.get_by_filter('type', 'date')

    def get_distance_items(self):
        return self.get_by_filter('type', 'distance')

    def get_duration_items(self):
        return self.get_by_filter('type', 'duration')

    def get_electric_power_items(self):
        return self.get_by_filter('type', 'electric power')

    def get_hex_color_items(self):
        return self.get_by_filter('type', 'hex color')

    def get_interval_items(self):
        return self.get_by_filter('type', 'interval')

    def get_ip_items(self):
        return self.get_by_filter('type', 'ip')

    def get_ipv6_items(self):
        return self.get_by_filter('type', 'ipv6')

    def get_light_intensity_items(self):
        return self.get_by_filter('type', 'light intensity')

    def get_mail_items(self):
        return self.get_by_filter('type', 'mail')

    def get_mass_items(self):
        return self.get_by_filter('type', 'mass')

    def get_mass_by_volume_items(self):
        return self.get_by_filter('type', 'mass by volume')

    def get_mol_items(self):
        return self.get_by_filter('type', 'mol')

    def get_money_items(self):
        return self.get_by_filter('type', 'money')

    def get_ordinal_items(self):
        return self.get_by_filter('type', 'ordinal')

    def get_percent_items(self):
        return self.get_by_filter('type', 'percent')

    def get_phone_items(self):
        return self.get_by_filter('type', 'phone')

    def get_pressure_items(self):
        return self.get_by_filter('type', 'pressure')

    def get_set_items(self):
        return self.get_by_filter('type', 'set')

    def get_speed_items(self):
        return self.get_by_filter('type', 'speed')

    def get_strength_items(self):
        return self.get_by_filter('type', 'strength')

    def get_surface_items(self):
        return self.get_by_filter('type', 'surface')

    def get_surface_tension_items(self):
        return self.get_by_filter('type', 'surface tension')

    def get_temperature_items(self):
        return self.get_by_filter('type', 'temperature')

    def get_time_items(self):
        return self.get_by_filter('type', 'time')

    def get_url_items(self):
        return self.get_by_filter('type', 'url')

    def get_voltage_items(self):
        return self.get_by_filter('type', 'voltage')

    def get_volume_items(self):
        return self.get_by_filter('type', 'volume')

    def get_happiness_items(self):
        return self.get_by_filter('type', 'happiness')

    def get_sadness_items(self):
        return self.get_by_filter('type', 'sadness')

    def get_fear_items(self):
        return self.get_by_filter('type', 'fear')

    def get_disgust_items(self):
        return self.get_by_filter('type', 'disgust')

    def get_anger_items(self):
        return self.get_by_filter('type', 'anger')

    def get_surprise_items(self):
        return self.get_by_filter('type', 'surprise')

    def get_judgement_items(self):
        return self.get_by_filter('type', 'judgement')



class Data():
	def __init__(self, data=None):
		self.data = data
		self.sentences = data
		self.lastIndex = -1

	def get(self):
		return self.data

	def map(self, function=None):
		if callable(function) and isinstance(self.data, list) :
			for item in self.data:
				function(item)
			return True
		return False

	def get_sentence(self, index=None):
		if index is not None:
			self.lastIndex = index
		else:
			index = self.lastIndex + 1
			self.lastIndex = index
		if not isinstance(self.data, type([])) or index >= len(self.data) or index < 0:
			return None
		return self.data[index]

	def get_number_of_sentences(self):
		if not self.data:
			return 0
		return len(self.data)



import requests
from .sentence import Sentence
from .data import Data

class Client:
	def __init__(self, key=None, raw=True):
		if not key:
			raise Exception('Missing key for initialization')
		if isinstance(key, str) is False:
			raise Exception('Wrong key format')
		if key.startswith('LettriaProKey'):
			key = key[14:]
		self.key = key
		self.raw = raw

	def get_key(self):
		if self.key:
			return self.key

	def set_key(self, key=None):
		if key:
			self.key = key
			return True
		return False

	def print_response_error(self, response):
		if 'Error' in response:
			print("Lettria SDK: \033[1;31;40mERROR:\033[0;37;40m {}".format(response['Error']))
		else:
			print(response)

	def server_request(self, text=''):
		response = None
		try:
			headers = { 'Authorization': 'LettriaProKey ' + str(self.key), 'content-type': 'application/json' }
			response = requests.post('https://api.lettria.com/main', headers=headers, json={'text' : text}).json()
		except Exception as e:
			print(e)
			pass
		if response and not isinstance(response, list):
			self.print_response_error(response)
			response = None
		return response

	def request(self, text='', raw=None):
		_raw = self.raw if raw == None else raw
		sentences_json = self.server_request(text)
		if _raw or not sentences_json:
			return sentences_json
		sentences = []
		for s in sentences_json:
			sentences.append(Sentence(s))
		return Data(sentences)



# coding: utf-8

from setuptools import setup, find_packages

setup(
    name="lettria",
    version="2.1.0",
    packages=find_packages(),
    description="Lettria official SDK for python",
    author="Victor",
    author_email="victor@lettria.com",
    url="https://github.com/Lettria/sdk-python",
    license="MIT",
    install_requires=[
      "requests>=2.10",
    ],
    keywords="lettria french nlp taln chatbot bigdata text analysis"
)
